/**
 * Cookie plugin
 *
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

/**
 * Create a cookie with the given name and value and other optional parameters.
 *
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Set the value of a cookie.
 * @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
 * @desc Create a cookie with all available options.
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Create a session cookie.
 * @example $.cookie('the_cookie', null);
 * @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
 *       used when the cookie was set.
 *
 * @param String name The name of the cookie.
 * @param String value The value of the cookie.
 * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
 * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
 *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
 *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
 *                             when the the browser exits.
 * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
 * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
 * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
 *                        require a secure protocol (like HTTPS).
 * @type undefined
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */

/**
 * Get the value of a cookie with the given name.
 *
 * @example $.cookie('the_cookie');
 * @desc Get the value of a cookie.
 *
 * @param String name The name of the cookie.
 * @return The value of the cookie.
 * @type String
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */
jQuery.cookie = function(name, value, options) {
    if (typeof value != 'undefined') { // name and value given, set cookie
        options = options || {};
        if (value === null) {
            value = '';
            options.expires = -1;
        }
        var expires = '';
        if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
            var date;
            if (typeof options.expires == 'number') {
                date = new Date();
                date.setTime(date.getTime() + (options.expires * 24 * 60 * 60 * 1000));
            } else {
                date = options.expires;
            }
            expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
        }
        // CAUTION: Needed to parenthesize options.path and options.domain
        // in the following expressions, otherwise they evaluate to undefined
        // in the packed version for some reason...
        var path = options.path ? '; path=' + (options.path) : '';
        var domain = options.domain ? '; domain=' + (options.domain) : '';
        var secure = options.secure ? '; secure' : '';
        document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
    } else { // only name given, get cookie
        var cookieValue = null;
        if (document.cookie && document.cookie != '') {
            var cookies = document.cookie.split(';');
            for (var i = 0; i < cookies.length; i++) {
                var cookie = jQuery.trim(cookies[i]);
                // Does this cookie string begin with the name we want?
                if (cookie.substring(0, name.length + 1) == (name + '=')) {
                    cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
                    break;
                }
            }
        }
        return cookieValue;
    }
};

function getStringDateTime(){
  var obj = $('#header .info');
  var obj2 = $('#title_header .today');
  var month = ['января', 'Февраля', 'марта', 'апреля', 'мая', 'июня', 'июля', 'августа', 'сентября', 'октября', 'ноября', 'декабря'];
  var day =   ['Воскресенье', 'Понедельник', 'Вторник', 'Среда', 'Четверг', 'Пятница', 'Суббота'];
  var dt = new Date();
  var dmonth = dt.getMonth()+1;
  var dday = dt.getDate();
  var min = dt.getMinutes();
  var chr = dt.getHours();
  if(obj.length)
     obj.html('<div id="day">'+ day[dt.getDay()] +'</div><div id="date">'+dday+'.'+(dmonth<10?'0'+dmonth:dmonth)+'.'+dt.getFullYear()+' <span id="time">'+(chr<10?'0'+chr:chr)+':'+(min<10?'0'+min:min)+'</span></div>');
  if(obj2.length)
     obj2.html('Сегодня: <strong>'+dday+'.'+(dmonth<10?'0'+dmonth:dmonth)+'.'+dt.getFullYear()+'</strong>, '+day[dt.getDay()]+'</div>');
};

setInterval(function(){
  getStringDateTime();
}, 10000);

$(document).ready(function(){

  (function(){
    var scrollNews = $('div.top-pane-block'),
        count = scrollNews.children().length,
        currentIndex = 0,
        playing = true,
        scroll = function(action){
          currentIndex += action;
          scrollNews.scrollTop(Math.abs(currentIndex%count) * 23);
        };
    
    scrollNews.find('div.control > span:first-child').click(function(){
      scroll(1);
    });
    
    scrollNews.find('div.control > span:nth-child(2)').click(function(){
      playing = !playing;
    });
    
    scrollNews.find('div.control > span:last-child').click(function(){
      scroll(-1);
    });
    
    setInterval(function(){
      playing && scroll(1);
    }, 10000);
    
  })();

  /* carousel */
   
  //grab the width and calculate left value
  //var item_width = $('div.photopress_top div.pane-content div.inner > div').height();
  //var left_value = item_width * (-1);
  
  var item_width = 107;
  var left_value = 0;
       
  //move the last item before first item, just in case user click prev button
  $('div.photopress_top div.pane-content div.inner > div:first').before($('div.photopress_top div.pane-content div.inner  > div:last'));
   
  //set the default item to the correct position
  $('div.photopress_top div.pane-content div.inner ').css({'top' : left_value});

  //if user clicked on prev button
  $('#scroller-top').click(function() {

      //get the right position           
      var left_indent = parseInt($('div.photopress_top div.pane-content div.inner ').css('top')) + item_width;

      //slide the item           
      $('div.photopress_top div.pane-content div.inner ').animate({'top' : left_indent}, 500,function(){   

          //move the last item and put it as first item              
          $('div.photopress_top div.pane-content div.inner  > div:first').before($('div.photopress_top div.pane-content div.inner  > div:last'));          

          //set the default item to correct position
          $('div.photopress_top div.pane-content div.inner ').css({'top' : left_value});
       
      });

      //cancel the link behavior           
      return false;
           
  });


  //if user clicked on next button
  $('#scroller-bottom').click(function() {
       
      //get the right position
      var left_indent = parseInt($('div.photopress_top div.pane-content div.inner ').css('top')) - item_width;
       
      //slide the item
      $('div.photopress_top div.pane-content div.inner ').animate({'top' : left_indent}, 500, function () {
           
          //move the first item and put it as last item
          $('div.photopress_top div.pane-content div.inner  > div:last').after($('div.photopress_top div.pane-content div.inner  > div:first'));                 
           
          //set the default item to correct position
          $('div.photopress_top div.pane-content div.inner ').css({'top' : left_value});
       
      });
                
      //cancel the link behavior
      return false;
       
  });
 

  getStringDateTime();
  
  // блок последних новостей справа
  var lastnews = $('div.last_news_right_block'),
      news_1 = lastnews.length && lastnews.find('div.view-content > div');
      
  if(lastnews.length){
    // проверяем существование кук
    var last = $.cookie('additional-m3');
    
    last && (last = Math.max(Math.min(parseInt(last), news_1.length), 2));
    !last && (last = Math.min(5, news_1.length));
    
    // если включенных новостей всего 2 штуки или меньше, то "отключаем" кнопку скрытия
    if(last <= 2){
      $('div.additional-m3 img.remove_element')[0].src = '/sites/all/themes/kmru/images/blocks/minus-dis.gif';
      $('div.additional-m3 img.remove_element')[0].style.cursor = 'default';
    }
    // если включенных новостей макс. кол-во, то "отключаем" кнопку добавления
    if(last == news_1.length){
      $('div.additional-m3 img.add_element')[0].src = '/sites/all/themes/kmru/images/blocks/plus-dis.gif';
      $('div.additional-m3 img.add_element')[0].style.cursor = 'default';
    }
    
    // скрываем ненужные новости
    for(var i=0; i<news_1.length; i++)
      if(i > last - 1)
        $(news_1[i]).addClass('hidden').hide();
        
    $('div.last_news_right_block').show();
    
    // обработка кнопки "добавить картинку"
    $('div.last_news_right_block img.add_element').click(function(){
      // находим первый скрытый элемент
      var n = $(this).parent().parent().next().find('div.hidden:first'),
          // вычисляем общее количество скрытых блоков
          ln = $(this).parent().parent().next().find('div.hidden').length,
          // определяем общее кол-во блоков
          lnmats = $(this).parent().parent().next().find('div').length;
      
      // если видимы еще не все новости
      if(n.length){
        // показываем еще одну
        n.show().removeClass('hidden');
        // ищем имя куки, с которым сейчас работаем
        var cook = $(this).parents('.view-news')[0].className.match(/(additional-m\d)/)[1],
            // ищем номер блока, с которым сейчас работаем
            block = $(this).parents('.view-news')[0].className.match(/additional-m(\d)/)[1],
            // в зависимости от блока берем макс. кол-во существующих элементов
            length = news_1.length;
        
        // стави куку
        $.cookie(cook, length - ln + 1, { expires: 10, path: '/' });
        
        // если включено макс. кол-во -> меняем кнопку
        if(length - ln + 1 == length){
          this.src = '/sites/all/themes/kmru/images/blocks/plus-dis.gif';
          this.style.cursor = 'default';
        }
        // если включено больше двух блоков, можно активировать кнопку удаления
        if(length - ln + 1 == 3){
          $(this).next()[0].src = '/sites/all/themes/kmru/images/blocks/minus.gif';
          $(this).next()[0].style.cursor = '';
        }
      }
    });
    
    // обработка кнопки скрытия блока
    $('div.last_news_right_block img.remove_element').click(function(){
      // сколько скрыто блоков в текущий момент
      var n = $(this).parent().parent().next().find('div.hidden'),
          // их кол-во
          ln = n.length,
          // всего блоков
          lnmats = $(this).parent().parent().next().children('div').length,
          // если скрытые блоки есть, то берем предыдущий
          // либо берем последний в списке, так как получаетс, что все видимы
          p = n.length ? $(n[0]).prev() : $(this).parent().parent().next().children(':last-child');

      // если блок нашелся и при этом скрыто столько блоков, чтобы оставалось как минимум 3
      if(p && n.length < lnmats-2){
        // скрываем блок
        p.hide().addClass('hidden');
        
        // определяем имя куки
        var cook = $(this).parents('.view-news')[0].className.match(/(additional-m\d)/)[1],
            // номер блока новостей
            block = $(this).parents('.view-news')[0].className.match(/additional-m(\d)/)[1],
            // определяем макс. в текущем блоке новостей
            length = news_1.length;

        // ставим куку
        $.cookie(cook, length - ln - 1, { expires: 10, path: '/' });
        // если скрыт хотя бы один элемент, то включаем кнопку добавления
        if(length - ln - 1 == length - 1){
          $(this).prev()[0].src = '/sites/all/themes/kmru/images/blocks/plus.gif';
          $(this).prev()[0].style.cursor = '';
        }
        // если скрыли макс элементов, то выключаем скрывающую кнопку
        if(length - ln - 1 == 2){
          this.src = '/sites/all/themes/kmru/images/blocks/minus-dis.gif';
          this.style.cursor = 'default';
        }
      }
    });
    
    // кнопка разворачивания блока
    $('div.last_news_right_block img.expand').click(function(){
      var pr = $(this).parent().parent();
      // собственно меняем состояние на противоположное у контента и подвала
      pr.next().toggle()
        .next().toggle();
      
      // меняем состояние у кнопок добавления/скрытия
      $(this).prev().toggle()
             .prev().toggle();
      
      // в зависимости от класса на кнопке, меняем ее направление
      if($(this).hasClass('collapsed')){
        this.src = '/sites/all/themes/kmru/images/blocks/expanded.png';
        $(this).removeClass('collapsed');
      }else{
        this.src = '/sites/all/themes/kmru/images/blocks/collapsed.png';
        $(this).addClass('collapsed');;
      }
    });
  }
      
  // берем два блока новостей
  var mats = $('div.additional_materials div.view-articles'),
      mats_1 = $(mats[0]).find('div.view-content > div'),
      mats_2 = mats.length > 1 ? $(mats[1]).find('div.view-content > div') : [];
  
  if(mats.length){
    
    // проверяем существование кук
    var adds = $.cookie('additional-m1');
    var talk = $.cookie('additional-m2');
    
    // если мы не находимся в статье типа "новость", 
    // то показываем либо сохраненное кол-во видимых новостей (не меньше 2, по умолчанию пять)
    if(!$('div.additional_materials.type_news').length){
      adds && (adds = Math.max(Math.min(parseInt(adds), mats_1.length), 2));
      !adds && (adds = Math.min(5, mats_1.length));
    // в новостных статьях показываем вначале всегда две
    }else
      adds = Math.min(2, mats_1.length);
    
    // если включенных новостей всего 2 штуки или меньше, то "отключаем" кнопку скрытия
    if(adds <= 2){
      $('div.additional-m1 img.remove_element')[0].src = '/sites/all/themes/kmru/images/blocks/minus-dis.gif';
      $('div.additional-m1 img.remove_element')[0].style.cursor = 'default';
    }
    // если включенных новостей макс. кол-во, то "отключаем" кнопку добавления
    if(adds == mats_1.length){
      $('div.additional-m1 img.add_element')[0].src = '/sites/all/themes/kmru/images/blocks/plus-dis.gif';
      $('div.additional-m1 img.add_element')[0].style.cursor = 'default';
    }
    
    if(!$('div.additional_materials.type_news').length){
      talk && (talk = Math.max(Math.min(parseInt(talk), mats_2.length), 2));
      !talk && (talk = Math.min(5, mats_2.length));
    }else
      talk = Math.min(2, mats_2.length);

    if(talk <= 2){
      $('div.additional-m2 img.remove_element')[0].src = '/sites/all/themes/kmru/images/blocks/minus-dis.gif';
      $('div.additional-m2 img.remove_element')[0].style.cursor = 'default';
    }
    if(talk == mats_2.length){
      $('div.additional-m2 img.add_element')[0].src = '/sites/all/themes/kmru/images/blocks/plus-dis.gif';
      $('div.additional-m2 img.add_element')[0].style.cursor = 'default';
    }
    
    // скрываем ненужные новости
    for(var i=0; i<mats_1.length; i++)
      if(i > adds - 1)
        $(mats_1[i]).addClass('hidden').hide();
        
    for(var i=0; i<mats_2.length; i++)
      if(i > talk - 1)
        $(mats_2[i]).addClass('hidden').hide();
    
    // после полной готовности отображаем на странице
    $('div.additional_materials').show();
    
    // обработка кнопки "добавить картинку"
    $('div.additional_materials img.add_element').click(function(){
      // находим первый скрытый элемент
      var n = $(this).parent().parent().next().find('div.hidden:first'),
          // вычисляем общее количество скрытых блоков
          ln = $(this).parent().parent().next().find('div.hidden').length,
          // определяем общее кол-во блоков
          lnmats = $(this).parent().parent().next().find('div').length;
      
      // если видимы еще не все новости
      if(n.length){
        // показываем еще одну
        n.show().removeClass('hidden');
        // ищем имя куки, с которым сейчас работаем
        var cook = $(this).parents('.view-articles')[0].className.match(/(additional-m\d)/)[1],
            // ищем номер блока, с которым сейчас работаем
            block = $(this).parents('.view-articles')[0].className.match(/additional-m(\d)/)[1],
            // в зависимости от блока берем макс. кол-во существующих элементов
            length = block == 1 ? mats_1.length : mats_2.length;
        
        // стави куку
        $.cookie(cook, length - ln + 1, { expires: 10, path: '/' });
        
        // если включено макс. кол-во -> меняем кнопку
        if(length - ln + 1 == length){
          this.src = '/sites/all/themes/kmru/images/blocks/plus-dis.gif';
          this.style.cursor = 'default';
        }
        // если включено больше двух блоков, можно активировать кнопку удаления
        if(length - ln + 1 == 3){
          $(this).next()[0].src = '/sites/all/themes/kmru/images/blocks/minus.gif';
          $(this).next()[0].style.cursor = '';
        }
      }
    });
    
    // обработка кнопки скрытия блока
    $('div.additional_materials img.remove_element').click(function(){
      // сколько скрыто блоков в текущий момент
      var n = $(this).parent().parent().next().find('div.hidden'),
          // их кол-во
          ln = n.length,
          // всего блоков
          lnmats = $(this).parent().parent().next().children('div').length,
          // если скрытые блоки есть, то берем предыдущий
          // либо берем последний в списке, так как получаетс, что все видимы
          p = n.length ? $(n[0]).prev() : $(this).parent().parent().next().children(':last-child');

      // если блок нашелся и при этом скрыто столько блоков, чтобы оставалось как минимум 3
      if(p && n.length < lnmats-2){
        // скрываем блок
        p.hide().addClass('hidden');
        
        // определяем имя куки
        var cook = $(this).parents('.view-articles')[0].className.match(/(additional-m\d)/)[1],
            // номер блока новостей
            block = $(this).parents('.view-articles')[0].className.match(/additional-m(\d)/)[1],
            // определяем макс. в текущем блоке новостей
            length = block == 1 ? mats_1.length : mats_2.length;

        // ставим куку
        $.cookie(cook, length - ln - 1, { expires: 10, path: '/' });
        // если скрыт хотя бы один элемент, то включаем кнопку добавления
        if(length - ln - 1 == length - 1){
          $(this).prev()[0].src = '/sites/all/themes/kmru/images/blocks/plus.gif';
          $(this).prev()[0].style.cursor = '';
        }
        // если скрыли макс элементов, то выключаем скрывающую кнопку
        if(length - ln - 1 == 2){
          this.src = '/sites/all/themes/kmru/images/blocks/minus-dis.gif';
          this.style.cursor = 'default';
        }
      }
    });
    
    // кнопка разворачивания блока
    $('div.additional_materials img.expand').click(function(){
      var pr = $(this).parent().parent();
      // собственно меняем состояние на противоположное у контента и подвала
      pr.next().toggle()
        .next().toggle();
      
      // меняем состояние у кнопок добавления/скрытия
      $(this).prev().toggle()
             .prev().toggle();
      
      // в зависимости от класса на кнопке, меняем ее направление
      if($(this).hasClass('collapsed')){
        this.src = '/sites/all/themes/kmru/images/blocks/expanded.png';
        $(this).removeClass('collapsed');
      }else{
        this.src = '/sites/all/themes/kmru/images/blocks/collapsed.png';
        $(this).addClass('collapsed');;
      }
    });
  }
  if ($('#full_text_button').length>0){
	  $('#full_text_button').toggle(
			  function(evt){
				  evt.preventDefault();
				  $(this).text('Свернуть');
				  $('#full_text').show();
			  },
			  function(evt){
				  evt.preventDefault();
				  $(this).text('Развернуть');
				  $('#full_text').hide();
			  }
	  );
  }
  
  if ($('#fact_field_see_more').length>0){
	  $('#fact_field_see_more').toggle(
			  function(evt){
				  evt.preventDefault();
				  $(this).text('Свернуть');
				  $('#more_fact_text').show('fade',function(){$(this).css('display','inline');});
			  },
			  function(evt){
				  evt.preventDefault();
				  $(this).text('Подробнее');
				  $('#more_fact_text').hide('fade');
			  }
	  );
  }
  
  //odnoklassniki.ru button init
  if(typeof ODKL != 'undefined')
  ODKL.init();
  
});

function isset () {
    // !No description available for isset. @php.js developers: Please update the function summary text file.
    // 
    // version: 1103.1210
    // discuss at: http://phpjs.org/functions/isset
    // +   original by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   improved by: FremyCompany
    // +   improved by: Onno Marsman
    // +   improved by: Rafał Kukawski
    // *     example 1: isset( undefined, true);
    // *     returns 1: false
    // *     example 2: isset( 'Kevin van Zonneveld' );
    // *     returns 2: true
    var a = arguments,
        l = a.length,
        i = 0,
        undef;
 
    if (l === 0) {
        throw new Error('Empty isset');
    }
 
    while (i !== l) {
        if (a[i] === undef || a[i] === null) {
            return false;
        }
        i++;
    }
    return true;
}